Learn R Programming

excelstrippr (version 0.1.2)

strip_na_percent: Remove Rows of a Data Frame by Percent NA Values

Description

Remove Rows of a Data Frame by Percent NA Values

Usage

strip_na_percent(.df, greater_than = 0.25)

Arguments

.df

a data.frame object

greater_than

double. The cutoff percent of NA values in a row to remove that row. Defaults to 0.25

Value

a data frame with specified rows removed.

Examples

Run this code
# NOT RUN {
df <- data.frame(A = runif(5), B = runif(5), C = runif(5))
df$B[3:4] <- NA
df$C[4] <- NA
strip_na_percent(df, greater_than = .5)
# }

Run the code above in your browser using DataLab