powered by
Promote Row to Column Names
promote_colnames(.df, rownum = 1)
a data frame
numeric. The row in the data frame to be promoted to column names
a data frame with the promoted row as column names
# NOT RUN { df <- data.frame(v1 = c("X", "123.45"), v2 = c("Y", "345.67")) promote_colnames(df) # }
Run the code above in your browser using DataLab