powered by
Remove Rows of a Data Frame by Percent NA Values
strip_na_percent(.df, greater_than = 0.25)
a data.frame object
double. The cutoff percent of NA values in a row to remove that row. Defaults to 0.25
a data frame with specified rows removed.
# NOT RUN { df <- data.frame(A = runif(5), B = runif(5), C = runif(5)) df$B[3:4] <- NA df$C[4] <- NA strip_na_percent(df, greater_than = .5) # }
Run the code above in your browser using DataLab